==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/ExtensionsV1beta1AllowedHostPathFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ExtensionsV1beta1AllowedHostPathFluentImpl<A extends ExtensionsV1beta1AllowedHostPathFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements ExtensionsV1beta1AllowedHostPathFluent<A>{

    private String pathPrefix;
    private Boolean readOnly;

    public ExtensionsV1beta1AllowedHostPathFluentImpl(){
    }
    public ExtensionsV1beta1AllowedHostPathFluentImpl(ExtensionsV1beta1AllowedHostPath instance){
            this.withPathPrefix(instance.getPathPrefix());

            this.withReadOnly(instance.isReadOnly());

    }

    public String getPathPrefix(){
            return this.pathPrefix;
    }

    public A withPathPrefix(String pathPrefix){
            this.pathPrefix=pathPrefix; return (A) this;
    }

    public Boolean hasPathPrefix(){
            return this.pathPrefix != null;
    }

    public Boolean isReadOnly(){
            return this.readOnly;
    }

    public A withReadOnly(Boolean readOnly){
            this.readOnly=readOnly; return (A) this;
    }

    public Boolean hasReadOnly(){
            return this.readOnly != null;
    }

    public A withNewReadOnly(boolean arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    public A withNewReadOnly(String arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ExtensionsV1beta1AllowedHostPathFluentImpl that = (ExtensionsV1beta1AllowedHostPathFluentImpl) o;
            if (pathPrefix != null ? !pathPrefix.equals(that.pathPrefix) :that.pathPrefix != null) return false;
            if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/ExtensionsV1beta1AllowedHostPathFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class ExtensionsV1beta1AllowedHostPathFluentImpl<A extends ExtensionsV1beta1AllowedHostPathFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements ExtensionsV1beta1AllowedHostPathFluent<A>{

    private String pathPrefix;
    private Boolean readOnly;

    public ExtensionsV1beta1AllowedHostPathFluentImpl(){
    }
    public ExtensionsV1beta1AllowedHostPathFluentImpl(ExtensionsV1beta1AllowedHostPath instance){
            this.withPathPrefix(instance.getPathPrefix());

            this.withReadOnly(instance.isReadOnly());

    }

    public String getPathPrefix(){
            return this.pathPrefix;
    }

    public A withPathPrefix(String pathPrefix){
            this.pathPrefix=pathPrefix; return (A) this;
    }

    public Boolean hasPathPrefix(){
            return this.pathPrefix != null;
    }

    public A withNewPathPrefix(String arg1){
            return (A)withPathPrefix(new String(arg1));
    }

    public A withNewPathPrefix(StringBuilder arg1){
            return (A)withPathPrefix(new String(arg1));
    }

    public A withNewPathPrefix(StringBuffer arg1){
            return (A)withPathPrefix(new String(arg1));
    }

    public Boolean isReadOnly(){
            return this.readOnly;
    }

    public A withReadOnly(Boolean readOnly){
            this.readOnly=readOnly; return (A) this;
    }

    public Boolean hasReadOnly(){
            return this.readOnly != null;
    }

    public A withNewReadOnly(String arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    public A withNewReadOnly(boolean arg1){
            return (A)withReadOnly(new Boolean(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ExtensionsV1beta1AllowedHostPathFluentImpl that = (ExtensionsV1beta1AllowedHostPathFluentImpl) o;
            if (pathPrefix != null ? !pathPrefix.equals(that.pathPrefix) :that.pathPrefix != null) return false;
            if (readOnly != null ? !readOnly.equals(that.readOnly) :that.readOnly != null) return false;
            return true;
    }




}
